@@ -2,12 +2,13 @@ use strict;
 use warnings;
 
 package Footprintless::App;
-$Footprintless::App::VERSION = '1.04';
+$Footprintless::App::VERSION = '1.05';
 # ABSTRACT: The base application class for fpl
 # PODNAME: Footprintless::App
 
 use App::Cmd::Setup -app;
 use Footprintless;
+use Footprintless::Util qw(dynamic_module_new);
 use Log::Any;
 
 my $logger = Log::Any->get_logger();
@@ -36,10 +37,18 @@ sub _new {
 }
 
 sub _configure_logging {
-    my ( $self, $level ) = @_;
-    require Log::Any::Adapter;
-    Log::Any::Adapter->set( 'Stderr',
-        log_level => Log::Any::Adapter::Util::numeric_level($level) );
+    my ( $self, %options ) = @_;
+
+    my $log_configurator_module =
+        footprintless()->entities()->get_entity('footprintless.log_configurator');
+    if ($log_configurator_module) {
+        dynamic_module_new($log_configurator_module)->configure(%options);
+    }
+    elsif ( $options{log_level} ) {
+        require Log::Any::Adapter;
+        Log::Any::Adapter->set( 'Stderr',
+            log_level => Log::Any::Adapter::Util::numeric_level( $options{log_level} ) );
+    }
 }
 
 sub footprintless {
@@ -56,9 +65,12 @@ sub get_command {
     my ( $self, @args ) = @_;
     my ( $command, $opt, @rest ) = $self->App::Cmd::get_command(@args);
 
-    if ( $opt->{log} ) {
-        $self->_configure_logging( delete( $opt->{log} ) );
-    }
+    $self->_configure_logging(
+        command   => $command,
+        opt       => $opt,
+        rest      => \@rest,
+        log_level => delete( $opt->{log} )
+    );
 
     return ( $command, $opt, @rest );
 }
@@ -112,7 +124,7 @@ Footprintless::App - The base application class for fpl
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 METHODS
 
