@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Factory;
-$Footprintless::Factory::VERSION = '1.04';
+$Footprintless::Factory::VERSION = '1.05';
 # ABSTRACT: The default factory for footprintless modules
 # PODNAME: Footprintless::Factory
 
@@ -95,10 +95,7 @@ sub _init {
         if ($plugin_modules) {
             foreach my $plugin_module (@$plugin_modules) {
                 $logger->debugf( 'registering plugin %s', $plugin_module );
-                my $plugin_module_path = $plugin_module;
-                $plugin_module_path =~ s/::/\//g;
-                require "$plugin_module_path.pm";    ## no critic
-                $self->register_plugin( $plugin_module->new() );
+                $self->register_plugin( Footprintless::Util::dynamic_module_new($plugin_module) );
             }
         }
     }
@@ -177,7 +174,7 @@ Footprintless::Factory - The default factory for footprintless modules
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 DESCRIPTION
 
