@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Overlay;
-$Footprintless::Overlay::VERSION = '1.04';
+$Footprintless::Overlay::VERSION = '1.05';
 # ABSTRACT: An overlay manager
 # PODNAME: Footprintless::Overlay
 
@@ -17,6 +17,7 @@ use Footprintless::Mixins qw (
     _sub_entity
 );
 use Footprintless::Util qw(
+    dynamic_module_new
     invalid_entity
     temp_dir
 );
@@ -138,7 +139,18 @@ sub _resolver {
           $resolver_coordinate
         ? $self->_entity($resolver_coordinate)
         : $self->_entity();
-    return Template::Resolver->new( $resolver_spec, @resolver_opts );
+
+    my $resolver;
+    my $resolver_factory = $self->_entity('footprintless.overlay.resolver_factory');
+    if ($resolver_factory) {
+        $logger->tracef( "using resolver_factory: %s", $resolver_factory );
+        $resolver =
+            dynamic_module_new($resolver_factory)->new_resolver( $resolver_spec, @resolver_opts );
+    }
+    else {
+        $resolver = Template::Resolver->new( $resolver_spec, @resolver_opts );
+    }
+    return $resolver;
 }
 
 sub _resolve_footprintless {
@@ -195,7 +207,7 @@ Footprintless::Overlay - An overlay manager
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -336,6 +348,37 @@ L<Footprintless::Mixins|Footprintless::Mixins>
 
 L<Template::Overlay|Template::Overlay>
 
+=item *
+
+L<Template::Resolver|Template::Resolver>
+
 =back
 
+=head1 CONFIGURATION
+
+This module can optionally be configured to use a customized resolver.  To
+do so, configure a resolver factory in your entities:
+
+    footprintless => {
+        overlay => {
+            resolver_factory => 'My::ResolverFactory'
+        }
+    }
+
+The resolver factory must have a C<new_resolver> method that takes a spec and
+a list of options and returns a C<Template::Resolver>, for example:
+
+    sub new_resolver {
+        my ($self, $resolver_spec, %resolver_opts) = @_;
+        return Template::Resolver->new(
+            $resolver_spec,
+            %resolver_opts,
+            additional_transforms => {
+                random => sub {
+                    my ($resolver_self, $value) = @_;
+                    return $value . rand();
+                }
+            });
+    }
+
 =cut
