@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Util;
-$Footprintless::Util::VERSION = '1.04';
+$Footprintless::Util::VERSION = '1.05';
 # ABSTRACT: A utility method package for common functionality in Footprintless
 # PODNAME: Footprintless::Util
 
@@ -14,6 +14,7 @@ our @EXPORT_OK = qw(
     agent
     clean
     default_command_runner
+    dynamic_module_new
     dumper
     exit_due_to
     extract
@@ -74,9 +75,15 @@ sub default_command_runner {
 
 sub dumper {
     require Data::Dumper;
-    my $dumper = Data::Dumper->new( \@_ );
-    $dumper->Indent(1);
-    return $dumper->Dump(@_);
+    return Data::Dumper->new( \@_ )->Indent(1)->Sortkeys(1)->Dump();
+}
+
+sub dynamic_module_new {
+    my ( $module, @args ) = @_;
+    my $module_path = $module;
+    $module_path =~ s/::/\//g;
+    require "$module_path.pm";    ## no critic
+    return $module->new(@args);
 }
 
 sub exit_due_to {
@@ -131,10 +138,7 @@ sub factory {
     my $factory;
     my $factory_module = $entities->get_entity('footprintless.factory');
     if ( $entities->get_entity('footprintless.factory') ) {
-        my $factory_module_path = $factory_module;
-        $factory_module_path =~ s/::/\//;
-        require "$factory_module_path.pm";    ## no critic
-        $factory = $factory_module->new( $entities, @options );
+        $factory = dynamic_module_new( $factory_module, $entities, @options );
     }
     else {
         require Footprintless::Factory;
@@ -235,7 +239,7 @@ Footprintless::Util - A utility method package for common functionality in Footp
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -288,6 +292,11 @@ C<Footprintless::CommandRunner>.
 Prints a dump of C<@to_dump> using C<Data::Dumper> with C<Data::Dumper::Indent>
 set to 1.
 
+=head2 dynamic_module_new($module_name, @new_args)
+
+Require's and creates a new instance of C<$module_name>, passing 
+C<@new_args> to the C<new> method.
+
 =head2 exit_due_to($reason, $verbose)
 
 If C<$reason> is an instance of 
